'use client';
import Link from 'next/link';
import { X, Home, Users, ClipboardList, User } from 'lucide-react';

export default function Sidebar({ isCollapsed, isMobileOpen, toggleMobileSidebar }) {
  const navItems = [
    { href: "/pages/dashboard", icon: Home, label: "Home" },
    { href: "/pages/user", icon: Users, label: "User" },
    { href: "/pages/admin/members", icon: Users, label: "Members" },
    { href: "/pages/assignments", icon: ClipboardList, label: "Assignments" },
    { href: "/pages/user/profile", icon: User, label: "My Profile" },
  ];

  return (
    <aside className={`
      fixed top-0 left-0 h-full bg-white dark:bg-gray-800 border-r border-gray-200 dark:border-gray-700 z-40
      transition-all duration-300
      ${isCollapsed ? 'w-20' : 'w-64'}
      ${isMobileOpen ? 'translate-x-0' : '-translate-x-full md:translate-x-0'}
    `}>
      <div className="p-4 h-full flex flex-col">
        {/* Mobile Close Button (visible only on mobile) */}
        <button 
          onClick={toggleMobileSidebar}
          className="md:hidden absolute top-4 right-4 p-1 rounded-full hover:bg-gray-100 dark:hover:bg-gray-700"
        >
          <X className="w-5 h-5" />
        </button>

        <div className={`flex items-center ${isCollapsed ? 'justify-center' : 'justify-between'} mb-6`}>
          {!isCollapsed && (
            <h2 className="text-2xl font-bold text-transparent bg-clip-text bg-gradient-to-r from-blue-600 to-purple-500">
              HrMaTe
            </h2>
          )}
        </div>

        <nav className="flex-1">
          <ul className="space-y-2">
            {navItems.map((item) => (
              <li key={item.href}>
                <Link
                  href={item.href}
                  className={`
                    flex items-center p-3 rounded-lg hover:bg-gray-100 dark:hover:bg-gray-700
                    ${isCollapsed ? 'justify-center' : 'px-4'}
                  `}
                  onClick={toggleMobileSidebar} // Close sidebar when clicking a link on mobile
                >
                  <item.icon className="w-5 h-5" />
                  {!isCollapsed && (
                    <span className="ml-3">{item.label}</span>
                  )}
                </Link>
              </li>
            ))}
          </ul>
        </nav>
      </div>
    </aside>
  );
}