"use client";

import { useEffect, useState } from "react";
import { databases, account } from "../../lib/appwrite";
import { ID } from "appwrite";

export default function AssignmentsPage() {
  const [assignments, setAssignments] = useState([]);
  const [submissionLinks, setSubmissionLinks] = useState({});
  const [userId, setUserId] = useState(null);
  const [loadingUser, setLoadingUser] = useState(true); // 🟡 Loading state

  // Fetch assignments and user on mount
  useEffect(() => {
    const fetchAssignments = async () => {
      try {
        const response = await databases.listDocuments(
          "67e1452b00016444b37f",
          "67f0f285001a1614b4e8"
        );
        setAssignments(response.documents);
      } catch (error) {
        console.error("Error fetching assignments:", error);
      }
    };

    const fetchUser = async () => {
      try {
        const user = await account.get();
        setUserId(user.$id);
      } catch (error) {
        console.error("User not logged in:", error);
      } finally {
        setLoadingUser(false); // ✅ Done loading
      }
    };

    fetchAssignments();
    fetchUser();
  }, []);

  const handleInputChange = (assignmentId, value) => {
    setSubmissionLinks({
      ...submissionLinks,
      [assignmentId]: value,
    });
  };

  const handleSubmit = async (assignmentId) => {
    if (!userId) {
      alert("User not logged in. Cannot submit.");
      return;
    }

    const submissionLink = submissionLinks[assignmentId];
    if (!submissionLink) {
      alert("Submission link is empty.");
      return;
    }

    try {
      await databases.createDocument(
        "67e1452b00016444b37f",
        "67f5ea0a000393d31806", // ✅ Replace with correct ID
        ID.unique(),
        {
          assignmentId,
          userId,
          submissionLink,
        }
      );
      alert("Submitted!");
    } catch (error) {
      console.error("Submission failed:", error);
      alert("Submission failed: " + error.message);
    }
  };

  if (loadingUser) {
    return <div>Loading...</div>; // Optional loading indicator
  }

  return (
    <div>
      <h1 className="text-2xl font-bold mb-4">Assignments</h1>

      {assignments.length === 0 ? (
        <p>No assignments available.</p>
      ) : (
        assignments.map((assignment) => (
          <div key={assignment.$id} className="mb-6 border p-4 rounded-lg">
            <h2 className="text-xl font-semibold">{assignment.title}</h2>
            <p className="text-gray-600">{assignment.description}</p>
            <p className="text-sm text-gray-400">
              Deadline: {assignment.deadline}
            </p>

            <input
              type="text"
              className="mt-2 border px-2 py-1 w-full"
              placeholder="Paste your GitHub/Firebase/Netlify link"
              value={submissionLinks[assignment.$id] || ""}
              onChange={(e) =>
                handleInputChange(assignment.$id, e.target.value)
              }
            />

            <button
              onClick={() => handleSubmit(assignment.$id)}
              className="mt-2 bg-blue-600 text-white px-4 py-1 rounded"
              disabled={!submissionLinks[assignment.$id]}
            >
              Submit
            </button>
          </div>
        ))
      )}
    </div>
  );
}
