'use client';

import { useEffect, useState } from "react";
import { getCurrentUserWithRole } from "../../../utils/auth";
import { databases, databaseId, membersCollectionId, Query } from "../../../lib/appwrite";
import { useRouter } from "next/navigation";

export default function UserProfilePage() {
  const router = useRouter();
  const [profile, setProfile] = useState(null);
  const [form, setForm] = useState({ name: '', phone: '' });
  const [docId, setDocId] = useState(null);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);

  useEffect(() => {
    async function fetchProfile() {
      try {
        setLoading(true);
        setError(null);
        
        const user = await getCurrentUserWithRole();
        console.log("User data:", user);
        
        if (!user) {
          throw new Error("Please login to access this page");
        }

        // Use the same DB ID as in your auth.js
        const dbId = "67e1452b00016444b37f";
        const collectionId = "67f0f1200006897dc192";

        const res = await databases.listDocuments(
          dbId,
          collectionId,
          [Query.equal('userId', user.$id)]
        );

        console.log("Profile data:", res);

        if (res.documents.length === 0) {
          throw new Error("No profile found for this user");
        }

        const data = res.documents[0];
        setDocId(data.$id);
        setProfile(data);
        setForm({ 
          name: data.name || user.name || '', 
          phone: data.phone || '' 
        });
        
      } catch (err) {
        console.error("Profile fetch error:", err);
        setError(err.message);
        if (err.message.includes("authenticated") || err.message.includes("login")) {
          router.push('/login');
        }
      } finally {
        setLoading(false);
      }
    }

    fetchProfile();
  }, [router]);

  const handleChange = (e) => {
    setForm({
      ...form,
      [e.target.name]: e.target.value
    });
  };

  const handleSubmit = async (e) => {
    e.preventDefault();
    try {
      if (!docId) throw new Error("No profile document found");
      
      // Use the same DB ID as above
      const dbId = "67e1452b00016444b37f";
      const collectionId = "67f0f1200006897dc192";

      await databases.updateDocument(
        dbId,
        collectionId,
        docId,
        form
      );
      alert("Profile updated successfully!");
    } catch (err) {
      console.error("Update error:", err);
      alert(err.message || "Failed to update profile");
    }
  };

  if (loading) return <div className="p-6">Loading profile...</div>;
  if (error) return <div className="p-6 text-red-500">{error}</div>;

  return (
    <div className="max-w-md mx-auto p-4">
      <form onSubmit={handleSubmit} className="bg-white rounded-lg shadow-md p-6 space-y-4">
        <h2 className="text-2xl font-bold text-gray-800">Your Profile</h2>
        
        <div className="space-y-2">
          <label className="block text-sm font-medium text-gray-700">Name</label>
          <input
            type="text"
            name="name"
            value={form.name}
            onChange={handleChange}
            className="w-full px-3 py-2 border rounded-md"
            required
          />
        </div>
        
        <div className="space-y-2">
          <label className="block text-sm font-medium text-gray-700">Phone</label>
          <input
            type="tel"
            name="phone"
            value={form.phone}
            onChange={handleChange}
            className="w-full px-3 py-2 border rounded-md"
          />
        </div>
        
        <button
          type="submit"
          className="w-full bg-blue-600 text-white py-2 rounded-md hover:bg-blue-700"
        >
          Update Profile
        </button>
      </form>
    </div>
  );
}